<?php
/*
| ----------------------------------------------------
| File        : class-widgets.php
| Project     : Special Recent Posts plugin for Wordpress
| Version     : 1.6
| Description : This file contains the widget
|               main class.
| Author      : Luca Grandicelli
| Author URL  : http://www.lucagrandicelli.com
| Plugin URL  : http://www.lucagrandicelli.com/special-recent-posts-plugin-for-wordpress/
| ----------------------------------------------------
*/

class WDG_SpecialRecentPosts extends WP_Widget {

/*
| ---------------------------------------------
| CLASS CONSTRUCTOR & DECONSTRUCTOR
| ---------------------------------------------
*/
	// Class Constructor.
	// In this section we define the widget global values.
	function WDG_SpecialRecentPosts() {
	
		// Setting up widget options.
        $widget_ops = array (
            'classname'   => __('Special Recent Posts', SRP_TRANSLATION_ID),
            'description' => __('The Special Recent Posts widget. Drag to configure.', SRP_TRANSLATION_ID)
        );
		
        // Assigning widget options.
		$this->WP_Widget('WDG_SpecialRecentPosts', __('Special Recent Posts', SRP_TRANSLATION_ID), $widget_ops);
	}
	
/*
| ---------------------------------------------
| WIDGET FORM DISPLAY METHOD
| ---------------------------------------------
*/
	// Main form widget method.
	function form($instance) {
	
		// Outputs the options form on widget panel.
		$this->buildWidgetForm($instance);
	}

/*
| ---------------------------------------------
| WIDGET UPDATE & MAIN METHODS
| ---------------------------------------------
*/
	// Main method for widget update process.
	function update($new_instance, $old_instance) {
	
		// Processes widget options to be saved.
		$instance = $old_instance;
		$instance["srp_post_type"]            =  $new_instance["srp_post_type"];
		$instance["srp_thumbnail_option"]     =  $new_instance["srp_thumbnail_option"];
		$instance["srp_order_post_option"]    =  $new_instance["srp_order_post_option"];
		$instance["srp_orderby_post_option"]  =  $new_instance["srp_orderby_post_option"];
		$instance["srp_filter_cat_option"]    =  $new_instance["srp_filter_cat_option"];
		$instance["srp_content_post_option"]  =  $new_instance["srp_content_post_option"];
		$instance["srp_post_date_option"]     =  $new_instance["srp_post_date_option"];
		$instance["srp_exclude_option"]       =  trim(strip_tags(strip_shortcodes($new_instance["srp_exclude_option"])));
		$instance["srp_include_option"]       =  trim(strip_tags(strip_shortcodes($new_instance["srp_include_option"])));
		$instance["srp_widget_title"]         =  trim(strip_tags(strip_shortcodes($new_instance["srp_widget_title"])));
		
		// Updating widget values.
		if (is_numeric(strip_tags($new_instance["srp_number_post_option"])) && (strip_tags($new_instance["srp_number_post_option"]) != "0") )
			$instance["srp_number_post_option"] = trim(strip_tags(strip_shortcodes($new_instance["srp_number_post_option"])));
			
		if (is_numeric(strip_tags($new_instance["srp_thumbnail_wdg_width"])))
			$instance["srp_thumbnail_wdg_width"] = trim(strip_tags(strip_shortcodes($new_instance["srp_thumbnail_wdg_width"])));
			
		if (is_numeric(strip_tags($new_instance["srp_thumbnail_wdg_height"])))
			$instance["srp_thumbnail_wdg_height"] = trim(strip_tags(strip_shortcodes($new_instance["srp_thumbnail_wdg_height"])));
			
		// Return new widget instance.
		return $instance;
	}
	
	// Main widget method. Main logic here.
	function widget($args, $instance) {
	
		// Extracting Arguments.
		extract($args, EXTR_SKIP);
		
		// Print Before Widget stuff.
		echo $before_widget;
		
		// Creating an instance of Special Posts Class.
		$srp = new SpecialRecentPosts($instance);
		
		// Display Posts.
		$srp->displayPosts();
		
		// Print After Widget stuff.
		echo $after_widget;
	}
	
/*
| ---------------------------------------------
|  METHODS
| ---------------------------------------------
*/
	
	// Build the widget admin form.
	function buildWidgetForm($instance) {
	
		if (empty($instance)) {
			
			// Loading default widget values.
			global $srp_default_widget_values;
			
			// Loading default plugin settings.
			$plugin_args = get_option('srp_plugin_options');
			
			// Merging default values with instance array, in case this is empty.
			$instance = wp_parse_args( (array) $instance, $srp_default_widget_values);
			
			// Setting up thumbnails widt and height to default values if this is the first run.
			if (!isset($instance["srp_thumbnail_wdg_width"])) {
				$instance["srp_thumbnail_wdg_width"] = $plugin_args["srp_thumbnail_width"];
			}
			
			if (!isset($instance["srp_thumbnail_wdg_height"])) {
				$instance["srp_thumbnail_wdg_height"] = $plugin_args["srp_thumbnail_height"];
			}
		}
?>
		<!-- BOF Widget Options -->
		<ul id="srp-widget-optionlist">
		
			<!-- Post Type Display. -->
			<li>
				<label for="<?php echo $this->get_field_id('srp_post_type'); ?>" class="srp-widget-label"><?php _e('Display Posts or Pages?', SRP_TRANSLATION_ID); ?></label>
				<select id="<?php echo $this->get_field_id('srp_post_type'); ?>" name="<?php echo $this->get_field_name('srp_post_type'); ?>" class="srp-widget-select">
					<option value="post" <?php selected($instance["srp_post_type"], 'post'); ?>><?php _e('Posts', SRP_TRANSLATION_ID); ?></option>
					<option value="page" <?php selected($instance["srp_post_type"], 'page'); ?>><?php _e('Pages', SRP_TRANSLATION_ID); ?></option>
				</select>
			</li>
			
			<!-- Widget Title Option. -->
			<li>
				<label for="<?php echo $this->get_field_id('srp_widget_title'); ?>" class="srp-widget-label"><?php _e('Enter Widget Title', SRP_TRANSLATION_ID); ?></label>
				<input type="text" id="<?php echo $this->get_field_id('srp_widget_title'); ?>" name="<?php echo $this->get_field_name('srp_widget_title'); ?>" value="<?php echo htmlspecialchars($instance["srp_widget_title"], ENT_QUOTES); ?>" size="30" />
			</li>
			
			<!-- Thumbnail Option. -->
			<li>
				<label for="<?php echo $this->get_field_id('srp_thumbnail_option'); ?>" class="srp-widget-label"><?php _e('Display Thumbnails?', SRP_TRANSLATION_ID); ?></label>
				<select id="<?php echo $this->get_field_id('srp_thumbnail_option'); ?>" name="<?php echo $this->get_field_name('srp_thumbnail_option'); ?>" class="srp-widget-select">
					<option value="yes" <?php selected($instance["srp_thumbnail_option"], 'yes'); ?>><?php _e('Yes', SRP_TRANSLATION_ID); ?></option>
					<option value="no" <?php selected($instance["srp_thumbnail_option"], 'no'); ?>><?php _e('No', SRP_TRANSLATION_ID); ?></option>
				</select>
			</li>
			
			<!-- Thumbnail Width. -->
			<li>
				<label for="<?php echo $this->get_field_id('srp_thumbnail_wdg_width'); ?>" class="srp-widget-label"><?php _e('Thumbnail Width', SRP_TRANSLATION_ID); ?></label>
				<small>(will override default settings)</small>
				<input type="text" id="<?php echo $this->get_field_id('srp_thumbnail_wdg_width'); ?>" name="<?php echo $this->get_field_name('srp_thumbnail_wdg_width'); ?>" value="<?php echo htmlspecialchars($instance["srp_thumbnail_wdg_width"], ENT_QUOTES); ?>" size="8" />px
			</li>
			
			<!-- Thumbnail Height. -->
			<li>
				<label for="<?php echo $this->get_field_id('srp_thumbnail_wdg_height'); ?>" class="srp-widget-label"><?php _e('Thumbnail Height', SRP_TRANSLATION_ID); ?></label>
				<small>(will override default settings)</small>
				<input type="text" id="<?php echo $this->get_field_id('srp_thumbnail_wdg_height'); ?>" name="<?php echo $this->get_field_name('srp_thumbnail_wdg_height'); ?>" value="<?php echo htmlspecialchars($instance["srp_thumbnail_wdg_height"], ENT_QUOTES); ?>" size="8" />px
			</li>
			
			<!-- Max number of posts Option. -->
			<li>
				<label for="<?php echo $this->get_field_id('srp_number_post_option'); ?>" class="srp-widget-label"><?php _e('Max number of posts/pages to display?', SRP_TRANSLATION_ID); ?></label>
				<input type="text" id="<?php echo $this->get_field_id('srp_number_post_option'); ?>" name="<?php echo $this->get_field_name('srp_number_post_option'); ?>" value="<?php echo stripslashes($instance['srp_number_post_option']); ?>" size="5" />
			</li>
			
			<!-- Post Order Display Option. -->
			<li>
				<label for="<?php echo $this->get_field_id('srp_order_post_option'); ?>" class="srp-widgetLabel"><?php _e('Select posts/pages order:', SRP_TRANSLATION_ID); ?></label>
				<select id="<?php echo $this->get_field_id('srp_order_post_option'); ?>" name="<?php echo $this->get_field_name('srp_order_post_option'); ?>" class="srp-widget-select">
					<option value="DESC" <?php selected($instance["srp_order_post_option"], 'DESC'); ?>><?php _e('Latest first (DESC)', SRP_TRANSLATION_ID); ?></option>
					<option value="ASC" <?php selected($instance["srp_order_post_option"], 'ASC'); ?>><?php _e('Oldest first (ASC)', SRP_TRANSLATION_ID); ?></option>
				</select>
			</li>
			
			<!-- Random Posts Option. -->
			<li>
				<input type="checkbox" id="<?php echo $this->get_field_id('srp_orderby_post_option'); ?>" name="<?php echo $this->get_field_name('srp_orderby_post_option'); ?>" value="rand" <?php checked($instance["srp_orderby_post_option"], 'rand'); ?> />
				<label for="<?php echo $this->get_field_id('srp_orderby_post_option'); ?>" class="srp-widget-label-inline"><?php _e('Enable Random mode', SRP_TRANSLATION_ID); ?></label>
			</li>
			
			<!-- Category Filter Option. -->
			<li>
				<label for="<?php echo $this->get_field_id('srp_filter_cat_option'); ?>" class="srp-widget-label"><?php _e('Category Filter:', SRP_TRANSLATION_ID); ?></label>
				<?php
				
				// Setting up category list option array.
				$catArgs = array (
					'show_option_none' => __('No category filter', SRP_TRANSLATION_ID),
					'id'               => $this->get_field_id('srp_filter_cat_option'),
					'name'             => $this->get_field_name('srp_filter_cat_option')
				);
				
				// If filter has been already applied, display selected category.
				if ($instance["srp_filter_cat_option"])
					$catArgs["selected"] = $instance["srp_filter_cat_option"];
					
				// Display custom category dropdown.
				wp_dropdown_categories($catArgs);
				?>
			</li>
			
			<!-- Display Content Option. -->
			<li>
				<label for="<?php echo $this->get_field_id('srp_content_post_option'); ?>" class="srp-widget-label"><?php _e('Content Display Mode', SRP_TRANSLATION_ID); ?></label>
				<select id="<?php echo $this->get_field_id('srp_content_post_option'); ?>" name="<?php echo $this->get_field_name('srp_content_post_option'); ?>" class="srp-widget-select">
					<option value="titleonly" <?php selected($instance["srp_content_post_option"], 'titleonly'); ?>><?php _e('Title only', SRP_TRANSLATION_ID); ?></option>
					<option value="titleexcerpt" <?php selected($instance["srp_content_post_option"], 'titleexcerpt'); ?>><?php _e('Title and Excerpt', SRP_TRANSLATION_ID); ?></option>
				</select>
			</li>
			
			<!-- Display Date Option. -->
			<li>
				<label for="<?php echo $this->get_field_id('srp_post_date_option'); ?>" class="srp-widget-label"><?php _e('Display post date?', SRP_TRANSLATION_ID); ?></label>
				<select id="<?php echo $this->get_field_id('srp_post_date_option'); ?>" name="<?php echo $this->get_field_name('srp_post_date_option'); ?>" class="srp_widget-select">
					<option value="yes" <?php selected($instance["srp_post_date_option"], 'yes'); ?>><?php _e('Yes', SRP_TRANSLATION_ID); ?></option>
					<option value="no" <?php selected($instance["srp_post_date_option"], 'no'); ?>><?php _e('No', SRP_TRANSLATION_ID); ?></option>
				</select>
			</li>
			
			<!-- Include Posts Option. -->
			<li>
				<label for="<?php echo $this->get_field_id('srp_include_option'); ?>" class="srp-widget-label-inline"><?php _e('Include Posts/Pages IDs', SRP_TRANSLATION_ID); ?></label>
				<input type="text" id="<?php echo $this->get_field_id('srp_include_option'); ?>" name="<?php echo $this->get_field_name('srp_include_option'); ?>" value="<?php echo htmlspecialchars($instance["srp_include_option"], ENT_QUOTES); ?>" size="30" /><br />
				<small><?php _e('Enter a comma separated list of posts/pages IDs. Leave blank for no specific inclusion.', SRP_TRANSLATION_ID); ?></small>
			</li>
			
			<!-- Exclude Posts Option. -->
			<li>
				<label for="<?php echo $this->get_field_id('srp_exclude_option'); ?>" class="srp-widget-label-inline"><?php _e('Exclude Posts/Pages IDs', SRP_TRANSLATION_ID); ?></label>
				<input type="text" id="<?php echo $this->get_field_id('srp_exclude_option'); ?>" name="<?php echo $this->get_field_name('srp_exclude_option'); ?>" value="<?php echo htmlspecialchars($instance["srp_exclude_option"], ENT_QUOTES); ?>" size="30" /><br />
				<small><?php _e('Enter a comma separated list of posts/pages IDs. Leave blank for no exclusion.', SRP_TRANSLATION_ID); ?></small>
			</li>
		</ul>
		<!-- EOF Widget Options -->
<?php
	}
}